==> redux-arena-0.7.1.tgz: package/es/core/sagas/arenaCurtainSaga.js <==
var _marked = /*#__PURE__*/regeneratorRuntime.mark(takeEverySceneBundleAction),
    _marked2 = /*#__PURE__*/regeneratorRuntime.mark(forkSagaWithContext),
    _marked3 = /*#__PURE__*/regeneratorRuntime.mark(initArenaCurtainSaga),
    _marked4 = /*#__PURE__*/regeneratorRuntime.mark(killArenaCurtainSaga),
    _marked5 = /*#__PURE__*/regeneratorRuntime.mark(saga);

import { ARENA_CURTAIN_LOAD_SCENE, ARENA_CURTAIN_LOAD_ASYNCSCENE, ARENA_CURTAIN_INIT_SAGA, ARENA_CURTAIN_CLEAR_REDUX, ARENA_CURTAIN_SET_STATE } from "../actionTypes";
import { takeEvery, take, put, fork, select, cancel, setContext, getContext } from "redux-saga/effects";
import { applySceneBundle, applyAsyncSceneBundle } from "./sceneBundleSaga";

function takeEverySceneBundleAction() {
  var _reducerKey, lastTask, action;

  return regeneratorRuntime.wrap(function takeEverySceneBundleAction$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          _context.next = 2;
          return getContext("_reducerKey");

        case 2:
          _reducerKey = _context.sent;
          lastTask = void 0;

        case 4:
          if (!true) {
            _context.next = 23;
            break;
          }

          _context.next = 7;
          return take([ARENA_CURTAIN_LOAD_ASYNCSCENE, ARENA_CURTAIN_LOAD_SCENE]);

        case 7:
          action = _context.sent;

          if (!(action.parentArenaReducerDict._arenaCurtain.reducerKey === _reducerKey)) {
            _context.next = 21;
            break;
          }

          if (!(lastTask && lastTask.isRunning())) {
            _context.next = 12;
            break;
          }

          _context.next = 12;
          return cancel(lastTask);

        case 12:
          if (!(action.type === ARENA_CURTAIN_LOAD_ASYNCSCENE)) {
            _context.next = 18;
            break;
          }

          _context.next = 15;
          return fork(applyAsyncSceneBundle, action);

        case 15:
          lastTask = _context.sent;
          _context.next = 21;
          break;

        case 18:
          _context.next = 20;
          return fork(applySceneBundle, action);

        case 20:
          lastTask = _context.sent;

        case 21:
          _context.next = 4;
          break;

        case 23:
        case "end":
          return _context.stop();
      }
    }
  }, _marked, this);
}

/**
 * Listen to the loading of each scene,
 * and handle different processing functions when handling scene switches.
 * 
 * @param {any} ctx 
 */

function forkSagaWithContext(ctx) {
  return regeneratorRuntime.wrap(function forkSagaWithContext$(_context2) {
    while (1) {
      switch (_context2.prev = _context2.next) {
        case 0:
          _context2.next = 2;
          return setContext(ctx);

        case 2:
          _context2.next = 4;
          return fork(takeEverySceneBundleAction);

        case 4:
        case "end":
          return _context2.stop();
      }
    }
  }, _marked2, this);
}

/**
 * It is used to initialize the ArenaSwitch layer.
 * 
 * @param {any} { reducerKey, setSagaTask } 
 */

function initArenaCurtainSaga(_ref) {
  var reducerKey = _ref.reducerKey,
      setSagaTask = _ref.setSagaTask,
      _ref$isWaitingSwitchA = _ref.isWaitingSwitchAction,
      isWaitingSwitchAction = _ref$isWaitingSwitchA === undefined ? false : _ref$isWaitingSwitchA;
  var sagaTask;
  return regeneratorRuntime.wrap(function initArenaCurtainSaga$(_context3) {
    while (1) {
      switch (_context3.prev = _context3.next) {
        case 0:
          _context3.next = 2;
          return fork(forkSagaWithContext, {
            _reducerKey: reducerKey
          });

        case 2:
          sagaTask = _context3.sent;

          setSagaTask(sagaTask);

        case 4:
        case "end":
          return _context3.stop();
      }
    }
  }, _marked3, this);
}

/**
 * It is used to cancel the task of the ArenaSwitch layer.
 * 
 * @param {any} { sagaTaskPromise } 
 */

function killArenaCurtainSaga(_ref2) {
  var sagaTaskPromise = _ref2.sagaTaskPromise,
      reducerKey = _ref2.reducerKey;

  var sagaTask, store, _ref3, reduxInfo;

  return regeneratorRuntime.wrap(function killArenaCurtainSaga$(_context4) {
    while (1) {
      switch (_context4.prev = _context4.next) {
        case 0:
          _context4.next = 2;
          return sagaTaskPromise;

        case 2:
          sagaTask = _context4.sent;

          if (!sagaTask) {
            _context4.next = 6;
            break;
          }

          _context4.next = 6;
          return cancel(sagaTask);

        case 6:
          _context4.next = 8;
          return getContext("store");

        case 8:
          store = _context4.sent;
          _context4.next = 11;
          return select(function (state) {
            return state[reducerKey];
          });

        case 11:
          _ref3 = _context4.sent;
          reduxInfo = _ref3.reduxInfo;

          if (!reduxInfo.sagaTask) {
            _context4.next = 16;
            break;
          }

          _context4.next = 16;
          return cancel(reduxInfo.sagaTask);

        case 16:
          if (reduxInfo.reducerKey) {
            store.removeReducer(reduxInfo.reducerKey);
          }
          store.removeReducer(reducerKey);

        case 18:
        case "end":
          return _context4.stop();
      }
    }
  }, _marked4, this);
}

export default function saga() {
  return regeneratorRuntime.wrap(function saga$(_context5) {
    while (1) {
      switch (_context5.prev = _context5.next) {
        case 0:
          _context5.next = 2;
          return takeEvery(ARENA_CURTAIN_INIT_SAGA, initArenaCurtainSaga);

        case 2:
          _context5.next = 4;
          return takeEvery(ARENA_CURTAIN_CLEAR_REDUX, killArenaCurtainSaga);

        case 4:
        case "end":
          return _context5.stop();
      }
    }
  }, _marked5, this);
}

==> redux-arena-0.8.0.tgz: package/es/core/sagas/arenaCurtainSaga.js <==
var _marked = /*#__PURE__*/regeneratorRuntime.mark(takeEverySceneBundleAction),
    _marked2 = /*#__PURE__*/regeneratorRuntime.mark(forkSagaWithContext),
    _marked3 = /*#__PURE__*/regeneratorRuntime.mark(initArenaCurtainSaga),
    _marked4 = /*#__PURE__*/regeneratorRuntime.mark(killArenaCurtainSaga),
    _marked5 = /*#__PURE__*/regeneratorRuntime.mark(saga);

import { ARENA_CURTAIN_LOAD_SCENE, ARENA_CURTAIN_INIT_SAGA, ARENA_CURTAIN_CLEAR_REDUX, ARENA_CURTAIN_SET_STATE, ARENA_STATETREE_NODE_DISABLE, ARENA_STATETREE_NODE_DELETE } from "../actionTypes";
import { takeEvery, take, put, fork, select, cancel, setContext, getContext } from "redux-saga/effects";
import { applySceneBundle, applyAsyncSceneBundle } from "./sceneBundleSaga";

function takeEverySceneBundleAction() {
  var _reducerKey, lastTask, action;

  return regeneratorRuntime.wrap(function takeEverySceneBundleAction$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          _context.next = 2;
          return getContext("_reducerKey");

        case 2:
          _reducerKey = _context.sent;
          lastTask = void 0;

        case 4:
          if (!true) {
            _context.next = 17;
            break;
          }

          _context.next = 7;
          return take(ARENA_CURTAIN_LOAD_SCENE);

        case 7:
          action = _context.sent;

          if (!(action.arenaReducerDict._arenaCurtain.reducerKey === _reducerKey)) {
            _context.next = 15;
            break;
          }

          if (!(lastTask && lastTask.isRunning())) {
            _context.next = 12;
            break;
          }

          _context.next = 12;
          return cancel(lastTask);

        case 12:
          _context.next = 14;
          return fork(applySceneBundle, action);

        case 14:
          lastTask = _context.sent;

        case 15:
          _context.next = 4;
          break;

        case 17:
        case "end":
          return _context.stop();
      }
    }
  }, _marked, this);
}

/**
 * Listen to the loading of each scene,
 * and handle different processing functions when handling scene switches.
 * 
 * @param {any} ctx 
 */

function forkSagaWithContext(ctx) {
  return regeneratorRuntime.wrap(function forkSagaWithContext$(_context2) {
    while (1) {
      switch (_context2.prev = _context2.next) {
        case 0:
          _context2.next = 2;
          return setContext(ctx);

        case 2:
          _context2.next = 4;
          return fork(takeEverySceneBundleAction);

        case 4:
        case "end":
          return _context2.stop();
      }
    }
  }, _marked2, this);
}

/**
 * It is used to initialize the ArenaSwitch layer.
 * 
 * @param {any} { reducerKey, setSagaTask } 
 */

function initArenaCurtainSaga(_ref) {
  var reducerKey = _ref.reducerKey,
      setSagaTask = _ref.setSagaTask,
      _ref$isWaitingSwitchA = _ref.isWaitingSwitchAction,
      isWaitingSwitchAction = _ref$isWaitingSwitchA === undefined ? false : _ref$isWaitingSwitchA;
  var sagaTask;
  return regeneratorRuntime.wrap(function initArenaCurtainSaga$(_context3) {
    while (1) {
      switch (_context3.prev = _context3.next) {
        case 0:
          _context3.next = 2;
          return fork(forkSagaWithContext, {
            _reducerKey: reducerKey
          });

        case 2:
          sagaTask = _context3.sent;

          setSagaTask(sagaTask);

        case 4:
        case "end":
          return _context3.stop();
      }
    }
  }, _marked3, this);
}

/**
 * It is used to cancel the task of the ArenaSwitch layer.
 * 
 * @param {any} { sagaTaskPromise } 
 */

function killArenaCurtainSaga(_ref2) {
  var sagaTaskPromise = _ref2.sagaTaskPromise,
      reducerKey = _ref2.reducerKey;

  var sagaTask, store, _ref3, reduxInfo;

  return regeneratorRuntime.wrap(function killArenaCurtainSaga$(_context4) {
    while (1) {
      switch (_context4.prev = _context4.next) {
        case 0:
          _context4.next = 2;
          return sagaTaskPromise;

        case 2:
          sagaTask = _context4.sent;

          if (!sagaTask) {
            _context4.next = 6;
            break;
          }

          _context4.next = 6;
          return cancel(sagaTask);

        case 6:
          _context4.next = 8;
          return getContext("store");

        case 8:
          store = _context4.sent;
          _context4.next = 11;
          return put({
            type: ARENA_STATETREE_NODE_DISABLE,
            reducerKey: reducerKey
          });

        case 11:
          _context4.next = 13;
          return select(function (state) {
            return state[reducerKey];
          });

        case 13:
          _ref3 = _context4.sent;
          reduxInfo = _ref3.reduxInfo;

          if (!(reduxInfo.reducerKey != null)) {
            _context4.next = 19;
            break;
          }

          _context4.next = 18;
          return put({
            type: ARENA_STATETREE_NODE_DELETE,
            reducerKey: reduxInfo.reducerKey
          });

        case 18:
          store.removeReducer(reduxInfo.reducerKey);

        case 19:
          store.removeReducer(reducerKey);

        case 20:
        case "end":
          return _context4.stop();
      }
    }
  }, _marked4, this);
}

export default function saga() {
  return regeneratorRuntime.wrap(function saga$(_context5) {
    while (1) {
      switch (_context5.prev = _context5.next) {
        case 0:
          _context5.next = 2;
          return takeEvery(ARENA_CURTAIN_INIT_SAGA, initArenaCurtainSaga);

        case 2:
          _context5.next = 4;
          return takeEvery(ARENA_CURTAIN_CLEAR_REDUX, killArenaCurtainSaga);

        case 4:
        case "end":
          return _context5.stop();
      }
    }
  }, _marked5, this);
}
